@@ -113,6 +113,8 @@ class Witter():
         self.retweetname = ""
         self.retweetid = ""
         self.retweettext = ""
+        self.selectedUser = ""
+
         #Set the Glade file
         #self.gladefile = "/usr/share/witter/witter.glade"  
         #self.wTree = gtk.glade.XML(self.gladefile) 
@@ -123,7 +125,7 @@ class Witter():
             "newTweet" : self.enterPressed,
             "getTweets" : self.updateSelectedView,
             "storecreds" : self.store_creds,
-            "getcccesstoken" : self.getAccessToken,
+            "getacesstoken" : self.getAccessToken,
             "on_timeline_clicked" : self.switchView,
             "on_mentions_clicked" : self.switchView,
             "on_direct_messages_clicked" : self.switchView,
@@ -131,8 +133,14 @@ class Witter():
             "on_trend_clicked" : self.switchView,
             "on_insert_clicked" : self.twitPic,
             "on_friends_clicked" : self.switchView,
-        "setProps" : self.setProps,
-        "nosetProps" : self.dontsetProps,
+            "on_Reply_clicked" : self.replyTo,
+            "on_Retweet_clicked" : self.reTweet,
+            "on_DirectMessage_clicked" : self.directMessage,
+            "on_Follow_clicked" : self.FollowUser,
+            "on_UnFollow_clicked" : self.UnFollowUser,
+            "on_cancel_clicked" : self.gtk_widget_hide,
+            "setProps" : self.setProps,
+            "nosetProps" : self.dontsetProps,
         }
         self.builder.connect_signals(dic)
         #self.wTree.signal_autoconnect( dic )
@@ -147,8 +155,18 @@ class Witter():
         friendsButton = self.builder.get_object("friends")
         okButton = self.builder.get_object("Ok")
         cancelButton = self.builder.get_object("Cancel")
+        okoauthButton = self.builder.get_object("Ok-oauth")
+
         propscancelButton = self.builder.get_object("props-cancel")
         refreshstoreButton = self.builder.get_object("refresh_store")
+        #action buttons for a tweet
+        replybutton = self.builder.get_object("Reply")
+        retweetbutton = self.builder.get_object("Retweet")
+        dmbutton = self.builder.get_object("DirectMessage")
+        followbutton = self.builder.get_object("Follow")
+        unfollowbutton = self.builder.get_object("UnFollow")
+        #usersTimelinebutton = self.builder.get_object("UsersTimeline")
+
         refreshButton.set_name("HildonButton-finger")
         tweetButton.set_name("HildonButton-finger")
         timelineButton.set_name("HildonButton-finger")
@@ -158,8 +176,16 @@ class Witter():
         friendsButton.set_name("HildonButton-finger")
         okButton.set_name("HildonButton-finger")
         cancelButton.set_name("HildonButton-finger")
+        okoauthButton.set_name("HildonButton-thumb")
         propscancelButton.set_name("HildonButton-finger")
         refreshstoreButton.set_name("HildonButton-finger")
+        #action buttons
+        replybutton.set_name("HildonButton-thumb")
+        retweetbutton.set_name("HildonButton-thumb")
+        dmbutton.set_name("HildonButton-thumb")
+        followbutton.set_name("HildonButton-thumb")
+        unfollowbutton.set_name("HildonButton-thumb")
+        #usersTimelinebutton.set_name("HildonButton-thumb")
 
         self.textcolour = "#FFFFFF"
         #
@@ -305,10 +331,11 @@ class Witter():
         pannedWindow.connect('vertical-movement', self.scrolling)
         #self.treeview.connect("button-press-event", self.build_menu, None);
         selection = self.treeview.get_selection()
-        selection.connect('changed', self.build_menu)
+        #selection.connect('changed', self.build_menu)
+        self.treeview.connect('row-activated', self.build_menu)
 
         # self.treeview.connect("changed", self.build_menu, None);
-        self.treeview.tap_and_hold_setup(self.urlmenu, callback=gtk.tap_and_hold_menu_position_top)
+        #self.treeview.tap_and_hold_setup(self.urlmenu, callback=gtk.tap_and_hold_menu_position_top)
     	#init the configDialog
         self.configDialog = None
         if (re.search("UserName", self.username)):
@@ -318,6 +345,7 @@ class Witter():
         self.start_refresh_threads()
 
 
+
     def quit(self, *args):
         #this is our end method called when window is closed
         print "Stop Wittering"
@@ -467,7 +495,10 @@ class Witter():
         self.window.show_all()
         self.window.connect("key-press-event", self.on_key_press)
         self.window.connect("window-state-event", self.on_window_state_change)
-
+        #hide the action buttons
+        self.builder.get_object("hbuttonbox-act1").hide_all()
+        self.builder.get_object("hbuttonbox-act2").hide_all()
+        self.builder.get_object("hbuttonbox-act3").hide_all()
         #this starts everything up
         gtk.main()
 
@@ -476,27 +507,27 @@ class Witter():
         #call the get method for whichever liststore we're viewing
         if (self.treeview.get_model() == self.liststore):
             #self.getTweets()
-	    refreshtask = witter.RefreshTask(self.getTweetsWrapper, self.showBusy)
-	    refreshtask.refresh()
+    	    refreshtask = witter.RefreshTask(self.getTweetsWrapper, self.showBusy)
+    	    refreshtask.refresh()
         elif (self.treeview.get_model() == self.dmliststore):
             refreshtask = witter.RefreshTask(self.getDMsWrapper, self.showBusy)
-	    refreshtask.refresh()
+            refreshtask.refresh()
         elif (self.treeview.get_model() == self.mentionliststore):
 
-	    refreshtask = witter.RefreshTask(self.getMentionsWrapper, self.showBusy)
-	    refreshtask.refresh()
+    	    refreshtask = witter.RefreshTask(self.getMentionsWrapper, self.showBusy)
+    	    refreshtask.refresh()
         elif (self.treeview.get_model() == self.publicliststore):
             refreshtask = witter.RefreshTask(self.getPublicWrapper, self.showBusy)
-	    refreshtask.refresh()
+            refreshtask.refresh()
         elif (self.treeview.get_model() == self.trendliststore):
-            refreshtask = witter.RefreshTask(self.getTrends, self.showBusy)
-	    refreshtask.refresh()
+            refreshtask = witter.RefreshTask(self.getTrendsWrapper, self.showBusy)
+            refreshtask.refresh()
         elif (self.treeview.get_model() == self.friendsliststore):
-            refreshtask = witter.RefreshTask(self.getFriends, self.showBusy)
-	    refreshtask.refresh()
+            refreshtask = witter.RefreshTask(self.getFriendsWrapper, self.showBusy)
+            refreshtask.refresh()
         elif (self.treeview.get_model() == self.searchliststore):
             refreshtask = witter.RefreshTask(self.getSearchWrapper, self.showBusy)
-	    refreshtask.refresh()
+            refreshtask.refresh()
 
 	self.builder.get_object("hbox1").hide_all()
 	self.builder.get_object("hbox2").hide_all()
@@ -817,8 +848,8 @@ class Witter():
         #overloading the tweet text input as the search criteria
         searchterm = self.builder.get_object("TweetText").get_text()
         if (auto == 1):
-		#auto search performed frrom the saved search
-		searchterm = self.search_terms
+    		#auto search performed frrom the saved search
+    		searchterm = self.search_terms
 
         #see if we have just an empty string (eg eroneous button press)
         if (searchterm == ""):
@@ -1116,7 +1147,8 @@ class Witter():
                 self.reply_to = None
                 #last thing to do is refresh main feed
                 self.tweetText.set_text("")
-                self.getTweets()
+                refreshtask = witter.RefreshTask(self.getTweetsWrapper, self.showBusy)
+                refreshtask.refresh()
             except IOError, e:
                 msg = 'Error posting tweet '
                 if hasattr(e, 'reason'):
@@ -1185,7 +1217,8 @@ class Witter():
                 self.reply_to = None
         		#last thing to do is refresh main feed
                 self.tweetText.set_text("")
-                self.getTweets()
+                refreshtask = witter.RefreshTask(self.getTweetsWrapper, self.showBusy)
+                refreshtask.refresh()
     	    except IOError, e:
                 msg = 'Error posting tweet '
                 if hasattr(e, 'reason'):
@@ -1262,6 +1295,9 @@ class Witter():
         #from one mode to the other
     	self.builder.get_object("hbox1").show_all()
     	self.builder.get_object("hbox2").show_all()
+        self.builder.get_object("hbuttonbox-act1").hide_all()
+        self.builder.get_object("hbuttonbox-act2").hide_all()
+        self.builder.get_object("hbuttonbox-act3").hide_all()
         self.tweetText.grab_focus()
         if event.keyval == gtk.keysyms.F6:
              # The "Full screen" hardware key has been pressed 
@@ -1303,67 +1339,93 @@ class Witter():
         return urlmenu
 
     def build_menu(self, widget, *args):
-        #a fairly standard menu create
-        #I put in the same options as I have buttons
-        # and linked to the same methods
-        self.menuItemURL.remove_submenu()
-        self.menuItemUserAction.remove_submenu()
+        #first hide the other controls
+        print "building menu"
+        self.builder.get_object("hbox1").hide_all()
+        self.builder.get_object("hbox2").hide_all()
+        #
+        #empty the url buttons
+        buttons = self.builder.get_object("hbuttonbox-act3").get_children()
+        for button in buttons:
+            self.builder.get_object("hbuttonbox-act3").remove(button)
+            button.destroy()
 
+        #we need to track how many buttons we create
+        #so we know when to create new horizontal button boxes
+        b = hildon.Button(gtk.HILDON_SIZE_THUMB_HEIGHT,
+                                                  hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        b.set_title('Dismiss')
+
+        b.connect("clicked", self.dismissActionButtons)
+        self.builder.get_object("hbuttonbox-act3").pack_end(b, expand=True)
+
+        #get the selection
         treeselection = self.treeview.get_selection()
         select1, select2 = treeselection.get_selected_rows()
         #entry1, entry2 = self.treeview.get_selection().get_selected()
         #we might one day have more than on element selected, for now we get 1 row
         try:
+            #we want to scroll to the right place in pannable area, *after* we've shown conrolls
+            #so the x/y need to be in the right scope
+            selectedItem = None
             if select2 != None:
+
                 for item in select2[0]:
+                    #bring the selected item to the top of the view
+
                     #we want to access field 3 which has or Tweet in it
                     entry = select1.get_value(select1.get_iter(item), 2)
                     #and we might as well list the person who provided the url
                     name = select1.get_value(select1.get_iter(item), 0)
                     id = select1.get_value(select1.get_iter(item), 4)
+                    selectedItem = item
+                    if re.search("http", entry):
+                        #convert the string to chunks deliniated on space (we assume the url 
+                        #has spaces around it 
+                        L = string.split(entry)
+                        for word in L :
+                            #find the 'word' which is our url
+                            if re.search("http", word):
+                                url = word
 
-                if re.search("http", entry):
-                    #convert the string to chunks deliniated on space (we assume the url 
-                    #has spaces around it 
-                    L = string.split(entry)
-                    for word in L :
-                        #find the 'word' which is our url
-                        if re.search("http", word):
-                            url = word
-                            menuUrls = gtk.Menu()
-                            menuItemLaunchURL = gtk.MenuItem(url)
-                            menuItemLaunchURL.connect("activate", self.openBrowser, url)
-                            menuUrls.append(menuItemLaunchURL)
-                            menuUrls.show()
-                            self.menuItemURL.set_submenu(menuUrls)
+                                b = hildon.Button(gtk.HILDON_SIZE_THUMB_HEIGHT,
+                                                  hildon.BUTTON_ARRANGEMENT_VERTICAL)
+                                b.set_title('Open Url')
+                                b.set_value(url)
+                                b.connect("clicked", self.openBrowser, url)
+                                self.builder.get_object("hbuttonbox-act3").pack_start(b, expand=True)
 
 
-                menuUserAct = gtk.Menu()
-                menuItemFollowUser = gtk.MenuItem("Follow: " + name)
-                menuItemFollowUser.connect("activate", self.FollowUser, name)
-                menuItemUnFollowUser = gtk.MenuItem("Unfollow: " + name)
-                menuItemUnFollowUser.connect("activate", self.UnFollowUser, name)
-                menuUserAct.append(menuItemFollowUser)
-                menuUserAct.append(menuItemUnFollowUser)
-                menuUserAct.show()
-                self.menuItemUserAction.set_submenu(menuUserAct)
-		self.reply_to = id
-		self.reply_to_name = name
-		self.retweettext = entry
+                    #rect = self.treeview.get_background_area(item, self.tvctweet)
+                    #x, y = self.treeview.convert_bin_window_to_tree_coords(rect.x, rect.y)
+
+                self.reply_to = id
+                self.reply_to_name = name
+                self.retweettext = entry
                 self.retweetname = name
-		self.retweetid = id
+                self.retweetid = id
 
         except IndexError:
             print "nothing selected"
 
+        self.builder.get_object("hbuttonbox-act1").show_all()
+        self.builder.get_object("hbuttonbox-act2").show_all()
+        self.builder.get_object("hbuttonbox-act3").show_all()
+        rect = self.treeview.get_background_area(selectedItem, self.tvctweet)
+        x, y = self.treeview.convert_bin_window_to_tree_coords(rect.x, rect.y)
 
+        self.builder.get_object("pannableArea").scroll_to(x, y + 100)
 
-        self.urlmenu.show_all()
-
-
+    def dismissActionButtons(self, widget):
+        self.builder.get_object("hbuttonbox-act1").hide_all()
+        self.builder.get_object("hbuttonbox-act2").hide_all()
+        self.builder.get_object("hbuttonbox-act3").hide_all()
 
     def FollowUser(self, widget, name, *args):
         #strip out the @ which isn't really part of the username
+        self.builder.get_object("hbuttonbox-act1").hide_all()
+        self.builder.get_object("hbuttonbox-act2").hide_all()
+        self.builder.get_object("hbuttonbox-act3").hide_all()
         name = name.replace("@", "")
         print "follow: " + name
 
@@ -1425,6 +1487,9 @@ class Witter():
             note.system_note_dialog(msg)
             print msg
     def UnFollowUser(self, widget, name, *args):
+        self.builder.get_object("hbuttonbox-act1").hide_all()
+        self.builder.get_object("hbuttonbox-act2").hide_all()
+        self.builder.get_object("hbuttonbox-act3").hide_all()
         #strip out the @ which isn't really part of the username
         name = name.replace("@", "")
         print "unfollow : " + name
@@ -1485,52 +1550,43 @@ class Witter():
             print msg
 
     def replyTo(self, widget, *args):
-	if (self.treeview.get_model() == self.searchliststore):
-		#we want to store the search terms, replace them with tweet text
-		#so we can restore the search terms afterwards
-		self.search_terms = self.tweetText.get_text()
+        self.builder.get_object("hbuttonbox-act1").hide_all()
+        self.builder.get_object("hbuttonbox-act2").hide_all()
+        self.builder.get_object("hbuttonbox-act3").hide_all()
+        self.builder.get_object("hbox2").show_all()
+    	if (self.treeview.get_model() == self.searchliststore):
+    		#we want to store the search terms, replace them with tweet text
+    		#so we can restore the search terms afterwards
+    		self.search_terms = self.tweetText.get_text()
         self.tweetText.set_text(self.reply_to_name + " ")
-	self.tweetText.grab_focus()
-	self.tweetText.set_position(len(self.reply_to_name) + 1);
+    	self.tweetText.grab_focus()
+    	self.tweetText.set_position(len(self.reply_to_name) + 1);
+
+
+    def directMessage(self, widget, *args):
+        self.builder.get_object("hbuttonbox-act1").hide_all()
+        self.builder.get_object("hbuttonbox-act2").hide_all()
+        self.builder.get_object("hbuttonbox-act3").hide_all()
+        self.builder.get_object("hbox2").show_all()
+        name = self.reply_to_name.replace("@", "")
+        if (self.treeview.get_model() == self.searchliststore):
+            #we want to store the search terms, replace them with tweet text
+            #so we can restore the search terms afterwards
+            self.search_terms = self.tweetText.get_text()
+
+        self.tweetText.set_text("d " + name + " ")
+        self.tweetText.grab_focus()
+        self.tweetText.set_position(len(self.reply_to_name) + 3);
 
     def reTweet(self, widget, *args):
-	    self.tweetText.set_text("RT:" + self.retweettext)
-	    self.tweetText.grab_focus()
+        self.builder.get_object("hbuttonbox-act1").hide_all()
+        self.builder.get_object("hbuttonbox-act2").hide_all()
+        self.builder.get_object("hbuttonbox-act3").hide_all()
+        self.builder.get_object("hbox2").show_all()
+        self.tweetText.set_text("RT:" + self.retweettext)
+        self.tweetText.grab_focus()
 
-  #      print "reTweet : " + self.retweetname + " message_id " +self.retweetid
-    #    #
-#	post = urllib.urlencode({ })
-   #     #build the request with the url and our post data
-   #     req = urllib2.Request('http://api.twitter.com/1/statuses/retweet/'+str(self.retweetid)+'L.json', post)
-        #setup the auth stuff
- #       auth_handler = urllib2.HTTPBasicAuthHandler()
-  #      auth_handler.add_password(realm='Twitter API',
-   #                           uri='http://api.twitter.com/1/statuses/retweet/'+str(self.retweetid)+'L.json',
-     #                         user=self.username,
-       #                       passwd=self.password)
-    #    opener = urllib2.build_opener(auth_handler)
-        # ...and install it globally so it can be used with urlopen.
-#	try:
-#		urllib2.install_opener(opener)
-#		json = urllib2.urlopen(req)
-#		hildon.hildon_banner_show_information(self.window,"","ReTweet Successful")
-#	except IOError, e:
-#	    msg = 'Error posting tweet '
-#	    if hasattr(e, 'reason'):
-#		    msg = msg + str(e.reason)
-#		    
-   #         if hasattr(e, 'code'):
-      #          if (e.code == 401):
-         #           reason = "Not authorised: check uid/pwd"
-	#	elif(e.code == 503):
-	#	    reason = "Service unavailable"
-           #     else:
-              #      reason = ""
-                #msg = msg +'Server returned ' + str(e.code) + " : " + reason
 
-#	    note = hildon.hildon_note_new_information(self.window, msg)
-   #         note.run()
-	#    note.destroy()
 
     def openBrowser(self, widget, url, *args):
         #open a url in a browser
@@ -1682,14 +1738,9 @@ class Witter():
              dialog = self.builder.get_object("OauthDialog")
              dialog.set_title("Twitter Credentials")
              dialog.connect("response", self.gtk_widget_hide)
-             retcode = gtk.Dialog.run(dialog)
+             dialog.show_all()
 
-             if retcode == gtk.RESPONSE_OK:
-                print "User pressed 'OK' button'"
 
-             else:
-                print "User pressed 'Cancel' button"
-                return
          except IOError, e:
             print "error"
             msg = 'Error retrieving tweets '
@@ -1716,6 +1767,7 @@ class Witter():
          access_token = twitter.getAccessToken(pin)
          print access_token
          self.access_token = access_token
+         self.builder.get_object("OauthDialog").hide_all()
          #need to save/store the access token
          #twitter = oauthtwitter.OAuthApi(self.CONSUMER_KEY, self.CONSUMER_SECRET, access_token)
          #user = twitter.GetUserInfo()
@@ -1785,6 +1837,8 @@ class Witter():
         print type
         self.switchViewTo(widget, type)
 
+    def showUsersTimeline(self, widget):
+        print "does nothing at the moment"
 
     def selectImage(self, widget):
         #bring up a file choser to let people select images
@@ -1949,41 +2003,52 @@ class Witter():
 		    self.searchrefresh.start(self.searchRefreshInterval * 60, self)
 	    print "end refresh setup"
 
-    def getTweetsWrapper(self, *args):
+    def getTweetsWrapper(self, autoval=None, *args):
 
-	    self.getTweets(auto=1)
+	    self.getTweets(auto=autoval)
 
 	    return "done"
 
-    def getDMsWrapper(self, *args):
+    def getDMsWrapper(self, autoval=None, *args):
 	    #we want to randomise the streams so they don't clash
 	    #time.sleep(random.randint(1, 30))
 	    #if (self.gettingTweets == False):
-	    self.getDMs(auto=1)
+	    self.getDMs(auto=autoval)
 
 	    return "done"
 
-    def getMentionsWrapper(self, *args):
+    def getMentionsWrapper(self, autoval=None, *args):
 	    #we want to randomise the streams so they don't clash
 	    #time.sleep(random.randint(1, 30))
 	    #if (self.gettingTweets == False):
-	    self.getMentions(auto=1)
+	    self.getMentions(auto=autoval)
 
 	    return "done"
 
-    def getPublicWrapper(self, *args):
+    def getPublicWrapper(self, autoval=None, *args):
 	    #we want to randomise the streams so they don't clash
 	    #time.sleep(random.randint(1, 30))
 	    #if (self.gettingTweets == False):
-	    self.getPublic(auto=1)
+	    self.getPublic(auto=autoval)
 	    return "done"
 
-    def getSearchWrapper(self, *args):
+    def getSearchWrapper(self, autoval=None, *args):
 
-	    self.getSearch(auto=1)
+	    self.getSearch(auto=autoval)
 
 	    return "done"
 
+    def getFriendsWrapper(self, autoval=None, *args):
+
+        self.getFriends()
+
+        return "done"
+    def getTrendsWrapper(self, autoval=None, *args):
+
+        self.getTrends()
+
+        return "done"
+
     def showBusy(self, increment, *args):
         #increment might be +1 or -1 to take the counter up or down
         self.busyCounter = self.busyCounter + increment
@@ -2001,44 +2066,55 @@ class Witter():
 
 
     def gesture(self, widget, direction, startx, starty):
-
-	     widget.scroll_to(0, 0)
-	     if (direction == 3):
-		if (self.treeview.get_model() == self.liststore):
-		    self.switchViewTo(self.treeview, "public")
-		elif (self.treeview.get_model() == self.dmliststore):
-		    self.switchViewTo(self.treeview, "mentions")
-		elif (self.treeview.get_model() == self.mentionliststore):
-		    self.switchViewTo(self.treeview, "timeline")
-		elif (self.treeview.get_model() == self.publicliststore):
-		    self.switchViewTo(self.treeview, "trends")
-		elif (self.treeview.get_model() == self.trendliststore):
-		    self.switchViewTo(self.treeview, "friends")
-		elif (self.treeview.get_model() == self.friendsliststore):
-		    self.switchViewTo(self.treeview, "search")
-		elif (self.treeview.get_model() == self.searchliststore):
-		    self.switchViewTo(self.treeview, "direct")
+        self.builder.get_object("hbuttonbox-act1").hide_all()
+        self.builder.get_object("hbuttonbox-act2").hide_all()
+        self.builder.get_object("hbuttonbox-act3").hide_all()
+        widget.scroll_to(0, 0)
+        if (direction == 3):
+    		if (self.treeview.get_model() == self.liststore):
+    		    self.switchViewTo(self.treeview, "public")
+    		elif (self.treeview.get_model() == self.dmliststore):
+    		    self.switchViewTo(self.treeview, "mentions")
+    		elif (self.treeview.get_model() == self.mentionliststore):
+    		    self.switchViewTo(self.treeview, "timeline")
+    		elif (self.treeview.get_model() == self.publicliststore):
+    		    self.switchViewTo(self.treeview, "trends")
+    		elif (self.treeview.get_model() == self.trendliststore):
+    		    self.switchViewTo(self.treeview, "friends")
+    		elif (self.treeview.get_model() == self.friendsliststore):
+    		    self.switchViewTo(self.treeview, "search")
+    		elif (self.treeview.get_model() == self.searchliststore):
+    		    self.switchViewTo(self.treeview, "direct")
 
 
-	     if (direction == 2):
-		if (self.treeview.get_model() == self.liststore):
-		    self.switchViewTo(self.treeview, "mentions")
-		elif (self.treeview.get_model() == self.dmliststore):
-		    self.switchViewTo(self.treeview, "search")
-		elif (self.treeview.get_model() == self.mentionliststore):
-		    self.switchViewTo(self.treeview, "direct")
-		elif (self.treeview.get_model() == self.publicliststore):
-		    self.switchViewTo(self.treeview, "timeline")
-		elif (self.treeview.get_model() == self.trendliststore):
-		    self.switchViewTo(self.treeview, "public")
-		elif (self.treeview.get_model() == self.friendsliststore):
-		    self.switchViewTo(self.treeview, "trends")
-		elif (self.treeview.get_model() == self.searchliststore):
-		    self.switchViewTo(self.treeview, "friends")
+        if (direction == 2):
+    		if (self.treeview.get_model() == self.liststore):
+    		    self.switchViewTo(self.treeview, "mentions")
+    		elif (self.treeview.get_model() == self.dmliststore):
+    		    self.switchViewTo(self.treeview, "search")
+    		elif (self.treeview.get_model() == self.mentionliststore):
+    		    self.switchViewTo(self.treeview, "direct")
+    		elif (self.treeview.get_model() == self.publicliststore):
+    		    self.switchViewTo(self.treeview, "timeline")
+    		elif (self.treeview.get_model() == self.trendliststore):
+    		    self.switchViewTo(self.treeview, "public")
+    		elif (self.treeview.get_model() == self.friendsliststore):
+    		    self.switchViewTo(self.treeview, "trends")
+    		elif (self.treeview.get_model() == self.searchliststore):
+    		    self.switchViewTo(self.treeview, "friends")
 
     def scrolling (self, widget, direction, startx, starty):
-	     self.builder.get_object("hbox1").hide_all()
-	     self.builder.get_object("hbox2").hide_all()
+         self.builder.get_object("hbox1").hide_all()
+         self.builder.get_object("hbox2").hide_all()
+         self.builder.get_object("hbuttonbox-act1").hide_all()
+         self.builder.get_object("hbuttonbox-act2").hide_all()
+         self.builder.get_object("hbuttonbox-act3").hide_all()
+
+
+    def buildActionButtons(self):
+        #method called when you click a tweet to build the buttons to show
+        #at the bottom of the window
+        replyButton = hildon.Button("Reply")
 
 if __name__ == "__main__":
     #this is just what initialises the app and calls run
